==> vue-layout-builder-0.0.3.tgz: package/tests/unit/components/LayoutBuilderIframe.spec.js <==
import { mount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Iframe from "../../../src/components/LayoutBuilderIframe.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Iframe.vue", () => {
  describe("state.iframeSrc is null", () => {
    describe("isHidden()", () => {
      const wrapper = mount(Iframe, { store: Store(state), localVue });

      it("returns true is iframeSrc is null", () => {
        expect(wrapper.vm.isHidden).toEqual(true);
      });
    });
  });

  describe("state.iframeSrc is not null", () => {
    const iframeSrc = "foo";
    const wrapper = mount(Iframe, {
      store: Store(Object.assign({}, state, { iframeSrc })),
      localVue
    });

    describe("iframeSrc()", () => {
      it("returns iframeSrc from the state", () => {
        expect(wrapper.vm.iframeSrc).toEqual(iframeSrc);
      });
    });

    describe("isHidden()", () => {
      it("returns false", () => {
        expect(wrapper.vm.isHidden).toEqual(false);
      });
    });
  });

  describe("cancel()", () => {
    const wrapper = mount(Iframe, { store, localVue });
    const stub = jest.fn();
    store.commit = stub;

    it("commits setIframeSrc with null to the store", () => {
      wrapper.vm.cancel();
      expect(stub).toHaveBeenCalledWith("setIframeSrc", null);
    });

    it("commits setCurrentlyEditableContent with null to the store", () => {
      wrapper.vm.cancel();
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });
  });

  describe("clicking on the overlay", () => {
    const wrapper = mount(Iframe, {
      store,
      localVue
    });
    const stub = jest.fn();

    wrapper.setMethods({ onBackgroundClick: stub });

    it("calls onBackgroundClick()", () => {
      wrapper.trigger("click");
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling onBackgroundClick", () => {
    describe("with the clicked event being the root element", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("calls cancel()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the clicked event not being the root element", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("does not call cancel()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element.firstChild
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("calling onKeyDown", () => {
    describe("with the keyCode being 27", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("calls cancel()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the keyCode not being 27", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("does not call cancel()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 13
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("firing contentEdited on the iframe", () => {
    const detail = {
      id: 1,
      element: {
        html: "foo",
        editUrl: "bar"
      }
    };
    const wrapper = mount(Iframe, {
      store,
      localVue
    });
    const stub = jest.fn();
    store.dispatch = stub;

    it("dispatches editContent on the store with the correct params", () => {
      wrapper.element.querySelector("iframe").dispatchEvent(
        new CustomEvent("contentEdited", {
          detail
        })
      );
      expect(stub).toHaveBeenCalledWith("editContent", detail);
    });
  });
});

==> vue-layout-builder-0.0.9.tgz: package/tests/unit/components/LayoutBuilderIframe.spec.js <==
import { mount, createLocalVue } from "@vue/test-utils";
import Vue from "vue/dist/vue";
import Vuex from "vuex";
import Iframe from "../../../src/components/LayoutBuilderIframe.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Iframe.vue", () => {
  describe("change iframeSrc", () => {
    describe("to a truthy value", () => {
      const stubbedStore = Store(
        Object.assign(state, {
          iframeSrc: false
        })
      );
      const wrapper = mount(Iframe, {
        store: stubbedStore,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ addKeyDownListener: stub });

      Vue.set(stubbedStore.state, "iframeSrc", "foo");

      it("calls addKeyDownListener()", () => {
        expect(stub).toHaveBeenCalled();
      });
    });

    describe("to a falsy value", () => {
      const stubbedStore = Store(
        Object.assign(state, {
          iframeSrc: "foo"
        })
      );
      const wrapper = mount(Iframe, {
        store: stubbedStore,
        localVue
      });
      const stub = jest.fn();
      wrapper.setMethods({ removeKeyDownListener: stub });

      Vue.set(stubbedStore.state, "iframeSrc", null);

      it("calls removeKeyDownListener()", () => {
        expect(stub).toHaveBeenCalled();
      });
    });
  });

  describe("state.iframeSrc is null", () => {
    describe("isHidden()", () => {
      const wrapper = mount(Iframe, {
        store: Store(
          Object.assign(state, {
            iframeSrc: null
          })
        ),
        localVue
      });

      it("returns true if iframeSrc is null", () => {
        expect(wrapper.vm.isHidden).toEqual(true);
      });
    });
  });

  describe("state.iframeSrc is not null", () => {
    const iframeSrc = "foo";
    const wrapper = mount(Iframe, {
      store: Store(Object.assign({}, state, { iframeSrc })),
      localVue
    });

    describe("iframeSrc()", () => {
      it("returns iframeSrc from the state", () => {
        expect(wrapper.vm.iframeSrc).toEqual(iframeSrc);
      });
    });

    describe("isHidden()", () => {
      it("returns false", () => {
        expect(wrapper.vm.isHidden).toEqual(false);
      });
    });
  });

  describe("cancel()", () => {
    const wrapper = mount(Iframe, { store, localVue });
    const stub = jest.fn();
    store.commit = stub;

    it("commits setIframeSrc with null to the store", () => {
      wrapper.vm.cancel();
      expect(stub).toHaveBeenCalledWith("setIframeSrc", null);
    });

    it("commits setCurrentlyEditableContent with null to the store", () => {
      wrapper.vm.cancel();
      expect(stub).toHaveBeenCalledWith("setCurrentlyEditableContent", null);
    });
  });

  describe("clicking on the overlay", () => {
    const wrapper = mount(Iframe, {
      store,
      localVue
    });
    const stub = jest.fn();

    wrapper.setMethods({ onBackgroundClick: stub });

    it("calls onBackgroundClick()", () => {
      wrapper.trigger("click");
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling onBackgroundClick", () => {
    describe("with the clicked event being the root element", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("calls cancel()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the clicked event not being the root element", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("does not call cancel()", () => {
        wrapper.vm.onBackgroundClick({
          target: wrapper.element.firstChild
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("calling onKeyDown", () => {
    describe("with the keyCode being 27", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("calls cancel()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 27
        });

        expect(stub).toHaveBeenCalled();
      });
    });

    describe("with the keyCode not being 27", () => {
      const wrapper = mount(Iframe, {
        store,
        localVue
      });
      const stub = jest.fn();

      wrapper.setMethods({ cancel: stub });

      it("does not call cancel()", () => {
        wrapper.vm.onKeyDown({
          keyCode: 13
        });

        expect(stub).not.toHaveBeenCalled();
      });
    });
  });

  describe("firing contentEdited on the iframe", () => {
    const detail = {
      id: 1,
      element: {
        html: "foo",
        editUrl: "bar"
      }
    };
    const wrapper = mount(Iframe, {
      store,
      localVue
    });
    const stub = jest.fn();
    store.dispatch = stub;

    it("dispatches editContent on the store with the correct params", () => {
      wrapper.element.querySelector("iframe").dispatchEvent(
        new CustomEvent("contentEdited", {
          detail
        })
      );
      expect(stub).toHaveBeenCalledWith("editContent", detail);
    });
  });

  describe("calling addKeyDownListener()", () => {
    let wrapper;
    let stub;

    beforeEach(() => {
      wrapper = mount(Iframe, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("adds a keydown listener and calls onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).toHaveBeenCalled();
    });
  });

  describe("calling removeKeyDownListener()", () => {
    let wrapper;
    let stub;

    beforeEach(() => {
      wrapper = mount(Iframe, {
        store,
        localVue
      });
      stub = jest.fn();
      wrapper.setMethods({ onKeyDown: stub });
    });

    it("removes the keydown listener and doesn't call onKeyDown()", () => {
      wrapper.vm.addKeyDownListener();
      wrapper.vm.removeKeyDownListener();
      window.dispatchEvent(new Event("keydown"));
      expect(stub).not.toHaveBeenCalled();
    });
  });
});
